==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/RETRIEVEDVALUEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for RETRIEVEDVALUEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RETRIEVEDVALUEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WSPROMPTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SOURCESEQUENCE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SOURCEDESC" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESTSEQUENCE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESTDESC" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RETRIEVEDVALUEID_Type", propOrder = {
    "wspromptid",
    "sourcesequence",
    "sourcedesc",
    "destsequence",
    "destdesc"
})
public class RETRIEVEDVALUEID_Type {

    @XmlElement(name = "WSPROMPTID", required = true)
    protected WSPROMPTID_Type wspromptid;
    @XmlElement(name = "SOURCESEQUENCE")
    protected long sourcesequence;
    @XmlElement(name = "SOURCEDESC")
    protected String sourcedesc;
    @XmlElement(name = "DESTSEQUENCE")
    protected long destsequence;
    @XmlElement(name = "DESTDESC")
    protected String destdesc;

    /**
     * Gets the value of the wspromptid property.
     * 
     * @return
     *     possible object is
     *     {@link WSPROMPTID_Type }
     *     
     */
    public WSPROMPTID_Type getWSPROMPTID() {
        return wspromptid;
    }

    /**
     * Sets the value of the wspromptid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WSPROMPTID_Type }
     *     
     */
    public void setWSPROMPTID(WSPROMPTID_Type value) {
        this.wspromptid = value;
    }

    /**
     * Gets the value of the sourcesequence property.
     * 
     */
    public long getSOURCESEQUENCE() {
        return sourcesequence;
    }

    /**
     * Sets the value of the sourcesequence property.
     * 
     */
    public void setSOURCESEQUENCE(long value) {
        this.sourcesequence = value;
    }

    /**
     * Gets the value of the sourcedesc property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSOURCEDESC() {
        return sourcedesc;
    }

    /**
     * Sets the value of the sourcedesc property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSOURCEDESC(String value) {
        this.sourcedesc = value;
    }

    /**
     * Gets the value of the destsequence property.
     * 
     */
    public long getDESTSEQUENCE() {
        return destsequence;
    }

    /**
     * Sets the value of the destsequence property.
     * 
     */
    public void setDESTSEQUENCE(long value) {
        this.destsequence = value;
    }

    /**
     * Gets the value of the destdesc property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESTDESC() {
        return destdesc;
    }

    /**
     * Sets the value of the destdesc property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESTDESC(String value) {
        this.destdesc = value;
    }

}

==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/RETRIEVEDVALUEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour RETRIEVEDVALUEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="RETRIEVEDVALUEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WSPROMPTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SOURCESEQUENCE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SOURCEDESC" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESTSEQUENCE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESTDESC" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RETRIEVEDVALUEID_Type", propOrder = {
    "wspromptid",
    "sourcesequence",
    "sourcedesc",
    "destsequence",
    "destdesc"
})
public class RETRIEVEDVALUEID_Type {

    @XmlElement(name = "WSPROMPTID", required = true)
    protected WSPROMPTID_Type wspromptid;
    @XmlElement(name = "SOURCESEQUENCE")
    protected long sourcesequence;
    @XmlElement(name = "SOURCEDESC")
    protected String sourcedesc;
    @XmlElement(name = "DESTSEQUENCE")
    protected long destsequence;
    @XmlElement(name = "DESTDESC")
    protected String destdesc;

    /**
     * Obtient la valeur de la propriété wspromptid.
     * 
     * @return
     *     possible object is
     *     {@link WSPROMPTID_Type }
     *     
     */
    public WSPROMPTID_Type getWSPROMPTID() {
        return wspromptid;
    }

    /**
     * Définit la valeur de la propriété wspromptid.
     * 
     * @param value
     *     allowed object is
     *     {@link WSPROMPTID_Type }
     *     
     */
    public void setWSPROMPTID(WSPROMPTID_Type value) {
        this.wspromptid = value;
    }

    /**
     * Obtient la valeur de la propriété sourcesequence.
     * 
     */
    public long getSOURCESEQUENCE() {
        return sourcesequence;
    }

    /**
     * Définit la valeur de la propriété sourcesequence.
     * 
     */
    public void setSOURCESEQUENCE(long value) {
        this.sourcesequence = value;
    }

    /**
     * Obtient la valeur de la propriété sourcedesc.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSOURCEDESC() {
        return sourcedesc;
    }

    /**
     * Définit la valeur de la propriété sourcedesc.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSOURCEDESC(String value) {
        this.sourcedesc = value;
    }

    /**
     * Obtient la valeur de la propriété destsequence.
     * 
     */
    public long getDESTSEQUENCE() {
        return destsequence;
    }

    /**
     * Définit la valeur de la propriété destsequence.
     * 
     */
    public void setDESTSEQUENCE(long value) {
        this.destsequence = value;
    }

    /**
     * Obtient la valeur de la propriété destdesc.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESTDESC() {
        return destdesc;
    }

    /**
     * Définit la valeur de la propriété destdesc.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESTDESC(String value) {
        this.destdesc = value;
    }

}
